@@ -17,7 +17,7 @@
 
    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
-   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+   Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 
    Written by Brian Fox (bfox@ai.mit.edu). */
 
@@ -49,7 +49,7 @@ read_function_name (prompt, window)
       REFERENCE *entry;
 
       entry = (REFERENCE *)xmalloc (sizeof (REFERENCE));
-      entry->label = savestring (function_doc_array[i].func_name);
+      entry->label = strdup (function_doc_array[i].func_name);
       entry->nodename = (char *)NULL;
       entry->filename = (char *)NULL;
 
