@@ -21,7 +21,7 @@
 
    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
-   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+   Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 
    Written by Brian Fox (bfox@ai.mit.edu). */
 
@@ -135,8 +135,10 @@ terminal_begin_using_terminal ()
 static void
 terminal_end_using_terminal ()
 {
+  if (term_goto)
+    tputs (tgoto (term_goto, 0, screenheight-1), 1, output_character_function);
+  
   send_to_terminal (term_end_use);
-  terminal_goto_xy (0, screenheight-1);
 }
 
 /* **************************************************************** */
@@ -630,10 +632,10 @@ terminal_prep_terminal ()
   ttybuff.c_cc[VMIN] = 1;
   ttybuff.c_cc[VTIME] = 0;
 
-  if (ttybuff.c_cc[VINTR] = '\177')
+  if (ttybuff.c_cc[VINTR] == '\177')
     ttybuff.c_cc[VINTR] = -1;
 
-  if (ttybuff.c_cc[VQUIT] = '\177')
+  if (ttybuff.c_cc[VQUIT] == '\177')
     ttybuff.c_cc[VQUIT] = -1;
 
   ioctl (tty, TCSETA, &ttybuff);
